CopyType class

A special type used with copy to copy fields from another map

Implemented types

Constructors

CopyType(Map<String, SqlType> source)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → Map<String, SqlType>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List
override
toSqlString() → String
Returns the string that will be part of SQL statement.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited