IndexInfo class

Information of an index

Constructors

IndexInfo(String table, List<String> columns, {bool unique = false, String? using, String? ops, String? where})

Properties

columns → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
ops → String?
The operation class. Example: jsonb_path_ops and varchar_pattern_ops. If null, default is assumed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → String
final
unique → bool
final
using → String?
Types of index. Example, gist and gin. If null, default is assumed.
final
where → String?
Conditional index
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited