PrimaryKeyType class

A special type used with primaryKey to define a primary key with multiple columns

Implemented types

Constructors

PrimaryKeyType(Iterable<String> columns)

Properties

columns → Iterable<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List
override
toSqlString() → String
Returns the string that will be part of SQL statement.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited