ReferenceType class abstract

Inheritance

Constructors

ReferenceType(String otype, {String constraint = notNull, String cascade = "", String column = fdOid})
factory

Properties

cascade → String
no setter
column → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
otype → String
Returns the name of the table having the primary key.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List
inherited
toSqlString() → String
Returns the string that will be part of SQL statement.
inherited
toSqlStringBy(bool deferred) → String
Returns the SQL statment depending on if the reference is deferred. By default, we mean the referenced table is not created yet.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited