sql_util library

Functions

encodeTextInLike(String text) → String
Encodes text to escape special characters, so it can be normal text when using as part of the LIKE clause.
encodeTextInRegex(String text) → String
Encodes text to escape special characters, so it can be normal text when using as part of the regular-expression clause (~ and `~*).